@@ -5,7 +5,9 @@ from itertools import izip_longest
 import locale
 #from pprint import pprint
 
-from messytables.dateparser import DATE_FORMATS
+import dateutil.parser as parser
+
+from messytables.dateparser import DATE_FORMATS, is_date
 
 
 class CellType(object):
@@ -95,6 +97,8 @@ class DateType(CellType):
 
     @classmethod
     def test(cls, value):
+        if not is_date(value):
+            return
         for v in cls.formats:
             ins = cls(v)
             try:
@@ -119,6 +123,19 @@ class DateType(CellType):
         return hash(self.__class__) + hash(self.format)
 
 
+class DateUtilType(CellType):
+    """ The date util type uses the dateutil library to
+    parse the dates. The advantage of this type over
+    DateType is the speed and better date detection. However,
+    it does not offer format detection.
+
+    Do not use this together with the DateType"""
+    guessing_weight = 3
+
+    def cast(self, value):
+        return parser.parse(value)
+
+
 TYPES = [StringType, IntegerType, FloatType, DecimalType, DateType]
 
 
@@ -134,6 +151,8 @@ def type_guess(rows, types=TYPES, strict=False):
     guesses = defaultdict(lambda: defaultdict(int))
     for row in rows:
         for i, cell in enumerate(row):
+            # add string guess so that we have at least one guess
+            guesses[i][StringType()] = 0
             for type in types:
                 if not cell.value:
                     continue
@@ -153,10 +172,12 @@ def type_guess(rows, types=TYPES, strict=False):
     return _columns
 
 
-def types_processor(types):
+def types_processor(types, strict=False):
     """ Apply the column types set on the instance to the
     current row, attempting to cast each cell to the specified
-    type. """
+    type.
+
+    Strict means that casting errors are not ignored"""
     def apply_types(row_set, row):
         if types is None:
             return row
@@ -165,6 +186,7 @@ def types_processor(types):
                 cell.value = type.cast(cell.value)
                 cell.type = type
             except:
-                pass
+                if strict and type and cell.value:
+                    raise
         return row
     return apply_types
