@@ -1,9 +1,10 @@
 import os
 import unittest
-import decimal
-from datetime import datetime
-from pprint import pprint
 import StringIO
+import urllib2
+
+from httpretty import HTTPretty
+from httpretty import httprettified
 
 
 def horror_fobj(name):
@@ -12,8 +13,20 @@ def horror_fobj(name):
 
 from messytables import *
 
-class RowSetTestCase(unittest.TestCase):
 
+class DateParserTest(unittest.TestCase):
+    def test_date_regex(self):
+        assert dateparser.is_date('2012 12 22')
+        assert dateparser.is_date('2012/12/22')
+        assert dateparser.is_date('2012-12-22')
+        assert dateparser.is_date('22.12.2012')
+        assert dateparser.is_date('12 12 22')
+        assert dateparser.is_date('22 Dec 2012')
+        assert dateparser.is_date('2012 12 22 13:17')
+        assert dateparser.is_date('2012 12 22 T 13:17')
+
+
+class ReadTest(unittest.TestCase):
     def test_read_simple_csv(self):
         fh = horror_fobj('simple.csv')
         table_set = CSVTableSet.from_fileobj(fh)
@@ -136,29 +149,6 @@ class RowSetTestCase(unittest.TestCase):
         assert 'Chirurgie' in data[12][0].value, \
             data[12][0].value
 
-    def test_type_guess(self):
-        csv_file = StringIO.StringIO('''
-            1,   2012/2/12, 2,   02 October 2011
-            2,   2012/2/12, 2,   02 October 2011
-            2.4, 2012/2/12, 1, 1 May 2011
-            foo, bar,       1000,
-            4.3, ,          42,  24 October 2012
-             ,   2012/2/12, 21,  24 December 2013''')
-        rows = CSVTableSet(csv_file).tables[0]
-        guessed_types = type_guess(rows)
-
-        assert guessed_types == [DecimalType(), DateType('%Y/%m/%d'), IntegerType(), DateType('%d %B %Y')], guessed_types
-
-    def test_type_guess_strict(self):
-        csv_file = StringIO.StringIO('''
-            1,   2012/2/12, 2,   2, 02 October 2011
-            2,   2012/2/12, 1.1,  , 1 May 2011
-            foo, bar,       "1500",   0,
-            4,   2012/2/12, 42,  -2, 24 October 2012''')
-        rows = CSVTableSet(csv_file).tables[0]
-        guessed_types = type_guess(rows, strict=True)
-        assert guessed_types == [StringType(), StringType(), DecimalType(), IntegerType(), DateType('%d %B %Y')], guessed_types
-
     def test_read_type_guess_simple(self):
         fh = horror_fobj('simple.csv')
         table_set = CSVTableSet.from_fileobj(fh)
@@ -197,5 +187,57 @@ class RowSetTestCase(unittest.TestCase):
         data = list(row_set)
         assert 4000 == len(data), len(data)
 
+
+class TypeGuessTest(unittest.TestCase):
+    def test_type_guess(self):
+        csv_file = StringIO.StringIO('''
+            1,   2012/2/12, 2,   02 October 2011
+            2,   2012/2/12, 2,   02 October 2011
+            2.4, 2012/2/12, 1,   1 May 2011
+            foo, bar,       1000,
+            4.3, ,          42,  24 October 2012
+             ,   2012/2/12, 21,  24 December 2013''')
+        rows = CSVTableSet(csv_file).tables[0]
+        guessed_types = type_guess(rows.sample)
+
+        assert guessed_types == [DecimalType(), DateType('%Y/%m/%d'), IntegerType(), DateType('%d %B %Y')], guessed_types
+
+    def test_type_guess_strict(self):
+        import locale
+        locale.setlocale(locale.LC_ALL, '')
+        csv_file = StringIO.StringIO('''
+            1,   2012/2/12, 2,      2,02 October 2011,"100.234354"
+            2,   2012/2/12, 1.1,    0,1 May 2011,"100,000,000.12"
+            foo, bar,       1500,   0,,"NaN"
+            4,   2012/2/12, 42,"-2,000",24 October 2012,"42"''')
+        rows = CSVTableSet(csv_file).tables[0]
+        guessed_types = type_guess(rows.sample, strict=True)
+        assert guessed_types == [StringType(), StringType(), DecimalType(), IntegerType(), DateType('%d %B %Y'), FloatType()], guessed_types
+
+    def test_guessing_does_padding(self):
+        csv_file = StringIO.StringIO('''
+            1,   , 2
+            2,   , 1.1
+            foo, , 1500''')
+        rows = CSVTableSet(csv_file).tables[0]
+        guessed_types = type_guess(rows.sample, strict=True)
+        assert len(guessed_types) == 3
+        assert guessed_types == [StringType(), StringType(), DecimalType()], guessed_types
+
+
+class TestStreamInput(unittest.TestCase):
+    @httprettified
+    def test_http_resource(self):
+        url = 'http://www.messytables.org/static/long.csv'
+        HTTPretty.register_uri(HTTPretty.GET, url,
+            body=horror_fobj('long.csv').read(),
+            content_type="application/csv")
+        fh = urllib2.urlopen(url)
+        table_set = CSVTableSet.from_fileobj(fh)
+        row_set = table_set.tables[0]
+        data = list(row_set)
+        assert 4000 == len(data), len(data)
+
+
 if __name__ == '__main__':
     unittest.main()
